geojsonio-deprecated: Deprecated functions in geojsonio
Description
-
lint: In the next version this function will be removed, defunct.
See geojsonlint::geojson_hint
-
validate: In the next version this function will be removed, defunct.
See geojsonlint::geojson_lint